<!-- 地区设备运行情况 -->
<template>
    <div class="data-overview">
        <div class="header">
            <div class="header-title">地区设备运行情况</div>
        </div>

        <div ref="chartRef" style="width: 100%; min-height: 800px"></div>
    </div>
</template>
<script lang="ts" name="DeviceRunningStatus" setup>
import { useMenuStore } from '@/store/menu';
import * as echarts from 'echarts';
import { usaJson, sichuanJson } from './map/mapdata.js';

const chartRef = ref<Record<string, any>>({});
const menu = useMenuStore();
let myChart: any = null;

const handleOptions = (x = [], y = []) => {
    const chart: any = chartRef.value;
    if (chart) {
        myChart = echarts.init(chart);
        echarts.registerMap('USA', sichuanJson, {
            Alaska: {
                left: -131,
                top: 25,
                width: 15,
            },
            Hawaii: {
                left: -110,
                top: 28,
                width: 5,
            },
            'Puerto Rico': {
                left: -76,
                top: 26,
                width: 2,
            },
        });
        const options = {
            tooltip: {
                trigger: 'item',
                showDelay: 0,
                transitionDuration: 0.2,
            },
            visualMap: {
                left: 'right',
                min: 500000,
                max: 38000000,
                inRange: {
                    color: [
                        '#313695',
                        '#4575b4',
                        '#74add1',
                        '#abd9e9',
                        '#e0f3f8',
                        '#ffffbf',
                        '#fee090',
                        '#fdae61',
                        '#f46d43',
                        '#d73027',
                        '#a50026',
                    ],
                },
                text: ['High', 'Low'],
                calculable: true,
            },
            series: [
                {
                    name: 'USA PopEstimates',
                    type: 'map',
                    roam: true,
                    map: 'USA',
                    emphasis: {
                        label: {
                            show: true,
                        },
                    },
                    data: [
                        { name: '成都市', value: 4822023 },
                        { name: '自贡市', value: 731449 },
                        { name: '攀枝花市', value: 6553255 },
                        { name: '泸州市', value: 2949131 },
                        { name: '德阳市', value: 38041430 },
                        { name: '绵阳市', value: 5187582 },
                        { name: '广元市', value: 3590347 },
                        { name: '遂宁市', value: 917092 },
                        { name: '内江市', value: 632323 },
                        { name: '乐山市', value: 19317568 },
                        { name: '南充市', value: 9919945 },
                        { name: '眉山市', value: 1392313 },
                        { name: '宜宾市', value: 1595728 },
                        { name: '广安市', value: 12875255 },
                        { name: '达州市', value: 6537334 },
                        { name: '雅安市', value: 3074186 },
                        { name: '巴中市', value: 2885905 },
                        { name: '资阳市', value: 4380415 },
                        { name: '阿坝藏族羌族自治州', value: 4601893 },
                        { name: '甘孜藏族自治州', value: 1329192 },
                        { name: '凉山彝族自治州', value: 5884563 },
                    ],
                },
            ],
        };
        nextTick(() => {
            myChart.setOption(options);
            window.addEventListener('resize', function () {
                myChart.resize();
            });
        });
    }
};

watch(
    () => menu.collapsed,
    (newX) => {
        setTimeout(() => {
            myChart.resize();
        }, 300);
    },
);

onMounted(() => {
    handleOptions();
});
</script>
<style scoped lang="less">
.data-overview {
    padding: 16px;
    .header {
        display: flex;
        align-items: center;
        justify-content: space-between;
        .header-title {
            border-left: 3px solid #3468ff;
            padding-left: 8px;
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #333333;
            line-height: 23px;
        }
    }
}
</style>
